@@ -419,8 +419,8 @@ impl DeviceInternal {
                     our_keys.iter().map(|(keygrip, fpr)| (keygrip, fpr)))
             });
 
-            let fpr = &our_keys_map.get(removed_keygrip).expect("have it");
-            self.keys.remove(&fpr);
+            let fpr = our_keys_map.get(removed_keygrip).expect("have it");
+            self.keys.remove(*fpr);
         }
 
         Ok(())
@@ -759,6 +759,7 @@ mod tests {
 
     use anyhow::Context;
 
+    use openpgp::KeyHandle;
     use openpgp::parse::Parse;
     use openpgp::policy::StandardPolicy;
     use openpgp::serialize::Serialize;
@@ -824,7 +825,7 @@ mod tests {
 
             for k in cert.keys().secret() {
                 agent.import(P,
-                             &cert, k.parts_as_secret().expect("have secret"),
+                             &cert, k.key().parts_as_secret().expect("have secret"),
                              true, true).await.expect("can import");
             }
         }
